# rmtoo-art-latex2

NAME
DESCRIPTION
CONFIGURATION
USAGE
SEE ALSO
HISTORY
AUTHOR
COPYRIGHT

## NAME

rmtoo-art-latex2 - requirements management tool: latex2 artifact

## DESCRIPTION

The rmtoo requirment management tool is able to output one topic and all possible subtopics including the containing requirements as a LaTeX output.

Each topic is output as one level logical structuring level. The outermost level will be a chapter, the next sub-topic will be a section and so on.

Text from the topic is directly copied into the document.

At the moment there is no possibility to configure the LaTeX output itself.

## CONFIGURATION

The key in the output configuration must be latex2.

There must be a value for the key output_filename inside the output configuration which names the file where the LaTeX output will be stored.

## USAGE

Typically the LaTeX file in included with include or input directly from the master LaTeX document. Please consult the file doc/latex2/requirements.tex document as an example.

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## HISTORY

This is called ’2’ because it is the second version of the LaTeX output module. The first module used a pre-topic method to handle the output - which is not supported anymore.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later